# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/http_router_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import http_router_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_http__router__pb2
from yandex.cloud.apploadbalancer.v1 import virtual_host_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/apploadbalancer/v1/http_router_service.proto',
  package='yandex.cloud.apploadbalancer.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9yandex/cloud/apploadbalancer/v1/http_router_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x31yandex/cloud/apploadbalancer/v1/http_router.proto\x1a\x32yandex/cloud/apploadbalancer/v1/virtual_host.proto\x1a\x1dyandex/cloud/validation.proto\"4\n\x14GetHttpRouterRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8b\x01\n\x16ListHttpRoutersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"u\n\x17ListHttpRoutersResponse\x12\x41\n\x0chttp_routers\x18\x01 \x03(\x0b\x32+.yandex.cloud.apploadbalancer.v1.HttpRouter\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x17\x44\x65leteHttpRouterRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"2\n\x18\x44\x65leteHttpRouterMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\"\x9e\x04\n\x17UpdateHttpRouterRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9d\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x44.yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x43\n\rvirtual_hosts\x18\x06 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.VirtualHost\x12\x44\n\rroute_options\x18\x08 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.RouteOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\x08\"2\n\x18UpdateHttpRouterMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\"\xe8\x03\n\x17\x43reateHttpRouterRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9d\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x44.yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x43\n\rvirtual_hosts\x18\x05 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.VirtualHost\x12\x44\n\rroute_options\x18\x07 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.RouteOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x07\"2\n\x18\x43reateHttpRouterMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\"\x85\x01\n\x1fListHttpRouterOperationsRequest\x12$\n\x0ehttp_router_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"r\n ListHttpRouterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x9f\t\n\x11HttpRouterService\x12\xa3\x01\n\x03Get\x12\x35.yandex.cloud.apploadbalancer.v1.GetHttpRouterRequest\x1a+.yandex.cloud.apploadbalancer.v1.HttpRouter\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/apploadbalancer/v1/httpRouters/{http_router_id}\x12\xa2\x01\n\x04List\x12\x37.yandex.cloud.apploadbalancer.v1.ListHttpRoutersRequest\x1a\x38.yandex.cloud.apploadbalancer.v1.ListHttpRoutersResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/apploadbalancer/v1/httpRouters\x12\xbb\x01\n\x06\x43reate\x12\x38.yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest\x1a!.yandex.cloud.operation.Operation\"T\x82\xd3\xe4\x93\x02$\"\x1f/apploadbalancer/v1/httpRouters:\x01*\xb2\xd2*&\n\x18\x43reateHttpRouterMetadata\x12\nHttpRouter\x12\xcc\x01\n\x06Update\x12\x38.yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest\x1a!.yandex.cloud.operation.Operation\"e\x82\xd3\xe4\x93\x02\x35\x32\x30/apploadbalancer/v1/httpRouters/{http_router_id}:\x01*\xb2\xd2*&\n\x18UpdateHttpRouterMetadata\x12\nHttpRouter\x12\xd4\x01\n\x06\x44\x65lete\x12\x38.yandex.cloud.apploadbalancer.v1.DeleteHttpRouterRequest\x1a!.yandex.cloud.operation.Operation\"m\x82\xd3\xe4\x93\x02\x32*0/apploadbalancer/v1/httpRouters/{http_router_id}\xb2\xd2*1\n\x18\x44\x65leteHttpRouterMetadata\x12\x15google.protobuf.Empty\x12\xda\x01\n\x0eListOperations\x12@.yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsRequest\x1a\x41.yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/apploadbalancer/v1/httpRouters/{http_router_id}/operationsBz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_http__router__pb2.DESCRIPTOR,yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETHTTPROUTERREQUEST = _descriptor.Descriptor(
  name='GetHttpRouterRequest',
  full_name='yandex.cloud.apploadbalancer.v1.GetHttpRouterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.GetHttpRouterRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=418,
)


_LISTHTTPROUTERSREQUEST = _descriptor.Descriptor(
  name='ListHttpRoutersRequest',
  full_name='yandex.cloud.apploadbalancer.v1.ListHttpRoutersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.apploadbalancer.v1.ListHttpRoutersRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.apploadbalancer.v1.ListHttpRoutersRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.apploadbalancer.v1.ListHttpRoutersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.apploadbalancer.v1.ListHttpRoutersRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=560,
)


_LISTHTTPROUTERSRESPONSE = _descriptor.Descriptor(
  name='ListHttpRoutersResponse',
  full_name='yandex.cloud.apploadbalancer.v1.ListHttpRoutersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_routers', full_name='yandex.cloud.apploadbalancer.v1.ListHttpRoutersResponse.http_routers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.apploadbalancer.v1.ListHttpRoutersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=679,
)


_DELETEHTTPROUTERREQUEST = _descriptor.Descriptor(
  name='DeleteHttpRouterRequest',
  full_name='yandex.cloud.apploadbalancer.v1.DeleteHttpRouterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.DeleteHttpRouterRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=681,
  serialized_end=736,
)


_DELETEHTTPROUTERMETADATA = _descriptor.Descriptor(
  name='DeleteHttpRouterMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.DeleteHttpRouterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.DeleteHttpRouterMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=738,
  serialized_end=788,
)


_UPDATEHTTPROUTERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1282,
  serialized_end=1327,
)

_UPDATEHTTPROUTERREQUEST = _descriptor.Descriptor(
  name='UpdateHttpRouterRequest',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_hosts', full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.virtual_hosts', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_options', full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.route_options', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEHTTPROUTERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=791,
  serialized_end=1333,
)


_UPDATEHTTPROUTERMETADATA = _descriptor.Descriptor(
  name='UpdateHttpRouterMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateHttpRouterMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1335,
  serialized_end=1385,
)


_CREATEHTTPROUTERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1282,
  serialized_end=1327,
)

_CREATEHTTPROUTERREQUEST = _descriptor.Descriptor(
  name='CreateHttpRouterRequest',
  full_name='yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_hosts', full_name='yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest.virtual_hosts', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_options', full_name='yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest.route_options', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEHTTPROUTERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1388,
  serialized_end=1876,
)


_CREATEHTTPROUTERMETADATA = _descriptor.Descriptor(
  name='CreateHttpRouterMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.CreateHttpRouterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.CreateHttpRouterMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1878,
  serialized_end=1928,
)


_LISTHTTPROUTEROPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListHttpRouterOperationsRequest',
  full_name='yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1931,
  serialized_end=2064,
)


_LISTHTTPROUTEROPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListHttpRouterOperationsResponse',
  full_name='yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2066,
  serialized_end=2180,
)

_LISTHTTPROUTERSRESPONSE.fields_by_name['http_routers'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_http__router__pb2._HTTPROUTER
_UPDATEHTTPROUTERREQUEST_LABELSENTRY.containing_type = _UPDATEHTTPROUTERREQUEST
_UPDATEHTTPROUTERREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEHTTPROUTERREQUEST.fields_by_name['labels'].message_type = _UPDATEHTTPROUTERREQUEST_LABELSENTRY
_UPDATEHTTPROUTERREQUEST.fields_by_name['virtual_hosts'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._VIRTUALHOST
_UPDATEHTTPROUTERREQUEST.fields_by_name['route_options'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._ROUTEOPTIONS
_CREATEHTTPROUTERREQUEST_LABELSENTRY.containing_type = _CREATEHTTPROUTERREQUEST
_CREATEHTTPROUTERREQUEST.fields_by_name['labels'].message_type = _CREATEHTTPROUTERREQUEST_LABELSENTRY
_CREATEHTTPROUTERREQUEST.fields_by_name['virtual_hosts'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._VIRTUALHOST
_CREATEHTTPROUTERREQUEST.fields_by_name['route_options'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._ROUTEOPTIONS
_LISTHTTPROUTEROPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetHttpRouterRequest'] = _GETHTTPROUTERREQUEST
DESCRIPTOR.message_types_by_name['ListHttpRoutersRequest'] = _LISTHTTPROUTERSREQUEST
DESCRIPTOR.message_types_by_name['ListHttpRoutersResponse'] = _LISTHTTPROUTERSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteHttpRouterRequest'] = _DELETEHTTPROUTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteHttpRouterMetadata'] = _DELETEHTTPROUTERMETADATA
DESCRIPTOR.message_types_by_name['UpdateHttpRouterRequest'] = _UPDATEHTTPROUTERREQUEST
DESCRIPTOR.message_types_by_name['UpdateHttpRouterMetadata'] = _UPDATEHTTPROUTERMETADATA
DESCRIPTOR.message_types_by_name['CreateHttpRouterRequest'] = _CREATEHTTPROUTERREQUEST
DESCRIPTOR.message_types_by_name['CreateHttpRouterMetadata'] = _CREATEHTTPROUTERMETADATA
DESCRIPTOR.message_types_by_name['ListHttpRouterOperationsRequest'] = _LISTHTTPROUTEROPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListHttpRouterOperationsResponse'] = _LISTHTTPROUTEROPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetHttpRouterRequest = _reflection.GeneratedProtocolMessageType('GetHttpRouterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETHTTPROUTERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.GetHttpRouterRequest)
  })
_sym_db.RegisterMessage(GetHttpRouterRequest)

ListHttpRoutersRequest = _reflection.GeneratedProtocolMessageType('ListHttpRoutersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTHTTPROUTERSREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListHttpRoutersRequest)
  })
_sym_db.RegisterMessage(ListHttpRoutersRequest)

ListHttpRoutersResponse = _reflection.GeneratedProtocolMessageType('ListHttpRoutersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTHTTPROUTERSRESPONSE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListHttpRoutersResponse)
  })
_sym_db.RegisterMessage(ListHttpRoutersResponse)

DeleteHttpRouterRequest = _reflection.GeneratedProtocolMessageType('DeleteHttpRouterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEHTTPROUTERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.DeleteHttpRouterRequest)
  })
_sym_db.RegisterMessage(DeleteHttpRouterRequest)

DeleteHttpRouterMetadata = _reflection.GeneratedProtocolMessageType('DeleteHttpRouterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEHTTPROUTERMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.DeleteHttpRouterMetadata)
  })
_sym_db.RegisterMessage(DeleteHttpRouterMetadata)

UpdateHttpRouterRequest = _reflection.GeneratedProtocolMessageType('UpdateHttpRouterRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEHTTPROUTERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEHTTPROUTERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateHttpRouterRequest)
  })
_sym_db.RegisterMessage(UpdateHttpRouterRequest)
_sym_db.RegisterMessage(UpdateHttpRouterRequest.LabelsEntry)

UpdateHttpRouterMetadata = _reflection.GeneratedProtocolMessageType('UpdateHttpRouterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEHTTPROUTERMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateHttpRouterMetadata)
  })
_sym_db.RegisterMessage(UpdateHttpRouterMetadata)

CreateHttpRouterRequest = _reflection.GeneratedProtocolMessageType('CreateHttpRouterRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEHTTPROUTERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEHTTPROUTERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateHttpRouterRequest)
  })
_sym_db.RegisterMessage(CreateHttpRouterRequest)
_sym_db.RegisterMessage(CreateHttpRouterRequest.LabelsEntry)

CreateHttpRouterMetadata = _reflection.GeneratedProtocolMessageType('CreateHttpRouterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEHTTPROUTERMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateHttpRouterMetadata)
  })
_sym_db.RegisterMessage(CreateHttpRouterMetadata)

ListHttpRouterOperationsRequest = _reflection.GeneratedProtocolMessageType('ListHttpRouterOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTHTTPROUTEROPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsRequest)
  })
_sym_db.RegisterMessage(ListHttpRouterOperationsRequest)

ListHttpRouterOperationsResponse = _reflection.GeneratedProtocolMessageType('ListHttpRouterOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTHTTPROUTEROPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.http_router_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListHttpRouterOperationsResponse)
  })
_sym_db.RegisterMessage(ListHttpRouterOperationsResponse)


DESCRIPTOR._options = None
_GETHTTPROUTERREQUEST.fields_by_name['http_router_id']._options = None
_LISTHTTPROUTERSREQUEST.fields_by_name['folder_id']._options = None
_LISTHTTPROUTERSREQUEST.fields_by_name['page_size']._options = None
_LISTHTTPROUTERSREQUEST.fields_by_name['page_token']._options = None
_LISTHTTPROUTERSREQUEST.fields_by_name['filter']._options = None
_DELETEHTTPROUTERREQUEST.fields_by_name['http_router_id']._options = None
_UPDATEHTTPROUTERREQUEST_LABELSENTRY._options = None
_UPDATEHTTPROUTERREQUEST.fields_by_name['http_router_id']._options = None
_UPDATEHTTPROUTERREQUEST.fields_by_name['name']._options = None
_UPDATEHTTPROUTERREQUEST.fields_by_name['description']._options = None
_UPDATEHTTPROUTERREQUEST.fields_by_name['labels']._options = None
_CREATEHTTPROUTERREQUEST_LABELSENTRY._options = None
_CREATEHTTPROUTERREQUEST.fields_by_name['folder_id']._options = None
_CREATEHTTPROUTERREQUEST.fields_by_name['name']._options = None
_CREATEHTTPROUTERREQUEST.fields_by_name['description']._options = None
_CREATEHTTPROUTERREQUEST.fields_by_name['labels']._options = None
_LISTHTTPROUTEROPERATIONSREQUEST.fields_by_name['http_router_id']._options = None
_LISTHTTPROUTEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTHTTPROUTEROPERATIONSREQUEST.fields_by_name['page_token']._options = None

_HTTPROUTERSERVICE = _descriptor.ServiceDescriptor(
  name='HttpRouterService',
  full_name='yandex.cloud.apploadbalancer.v1.HttpRouterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2183,
  serialized_end=3366,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.apploadbalancer.v1.HttpRouterService.Get',
    index=0,
    containing_service=None,
    input_type=_GETHTTPROUTERREQUEST,
    output_type=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_http__router__pb2._HTTPROUTER,
    serialized_options=b'\202\323\344\223\0022\0220/apploadbalancer/v1/httpRouters/{http_router_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.apploadbalancer.v1.HttpRouterService.List',
    index=1,
    containing_service=None,
    input_type=_LISTHTTPROUTERSREQUEST,
    output_type=_LISTHTTPROUTERSRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/apploadbalancer/v1/httpRouters',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.apploadbalancer.v1.HttpRouterService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEHTTPROUTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002$\"\037/apploadbalancer/v1/httpRouters:\001*\262\322*&\n\030CreateHttpRouterMetadata\022\nHttpRouter',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.apploadbalancer.v1.HttpRouterService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEHTTPROUTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002520/apploadbalancer/v1/httpRouters/{http_router_id}:\001*\262\322*&\n\030UpdateHttpRouterMetadata\022\nHttpRouter',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.apploadbalancer.v1.HttpRouterService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEHTTPROUTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0022*0/apploadbalancer/v1/httpRouters/{http_router_id}\262\322*1\n\030DeleteHttpRouterMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.apploadbalancer.v1.HttpRouterService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTHTTPROUTEROPERATIONSREQUEST,
    output_type=_LISTHTTPROUTEROPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002=\022;/apploadbalancer/v1/httpRouters/{http_router_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HTTPROUTERSERVICE)

DESCRIPTOR.services_by_name['HttpRouterService'] = _HTTPROUTERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/vpc/v1/subnet_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.vpc.v1 import subnet_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.reference import reference_pb2 as yandex_dot_cloud_dot_reference_dot_reference__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/vpc/v1/subnet_service.proto',
  package='yandex.cloud.vpc.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(yandex/cloud/vpc/v1/subnet_service.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/vpc/v1/subnet.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/reference/reference.proto\"3\n\x10GetSubnetRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8f\x01\n\x12ListSubnetsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\\\n\x13ListSubnetsResponse\x12,\n\x07subnets\x18\x01 \x03(\x0b\x32\x1b.yandex.cloud.vpc.v1.Subnet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xf7\x03\n\x13\x43reateSubnetRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x85\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x34.yandex.cloud.vpc.v1.CreateSubnetRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12 \n\nnetwork_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x07zone_id\x18\x06 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x0ev4_cidr_blocks\x18\x07 \x03(\tB\x04\xe8\xc7\x31\x01\x12 \n\x0eroute_table_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x36\n\x0c\x64hcp_options\x18\n \x01(\x0b\x32 .yandex.cloud.vpc.v1.DhcpOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x14\x43reateSubnetMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\"\xc9\x03\n\x13UpdateSubnetRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x85\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x34.yandex.cloud.vpc.v1.UpdateSubnetRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12 \n\x0eroute_table_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x36\n\x0c\x64hcp_options\x18\x07 \x01(\x0b\x32 .yandex.cloud.vpc.v1.DhcpOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x14UpdateSubnetMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\"U\n\x1a\x41\x64\x64SubnetCidrBlocksRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x16\n\x0ev4_cidr_blocks\x18\x02 \x03(\t\"0\n\x1b\x41\x64\x64SubnetCidrBlocksMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\"X\n\x1dRemoveSubnetCidrBlocksRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x16\n\x0ev4_cidr_blocks\x18\x02 \x03(\t\"3\n\x1eRemoveSubnetCidrBlocksMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\"6\n\x13\x44\x65leteSubnetRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x14\x44\x65leteSubnetMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\"|\n\x1bListSubnetOperationsRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x1cListSubnetOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"a\n\x11MoveSubnetRequest\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\'\n\x12MoveSubnetMetadata\x12\x11\n\tsubnet_id\x18\x01 \x01(\t\"j\n\x18ListUsedAddressesRequest\x12\x17\n\tsubnet_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"i\n\x19ListUsedAddressesResponse\x12\x33\n\taddresses\x18\x01 \x03(\x0b\x32 .yandex.cloud.vpc.v1.UsedAddress\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x89\x01\n\x0bUsedAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x32\n\nip_version\x18\x02 \x01(\x0e\x32\x1e.yandex.cloud.vpc.v1.IpVersion\x12\x35\n\nreferences\x18\x03 \x03(\x0b\x32!.yandex.cloud.reference.Reference2\xcf\x0c\n\rSubnetService\x12n\n\x03Get\x12%.yandex.cloud.vpc.v1.GetSubnetRequest\x1a\x1b.yandex.cloud.vpc.v1.Subnet\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/vpc/v1/subnets/{subnet_id}\x12r\n\x04List\x12\'.yandex.cloud.vpc.v1.ListSubnetsRequest\x1a(.yandex.cloud.vpc.v1.ListSubnetsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/vpc/v1/subnets\x12\x93\x01\n\x06\x43reate\x12(.yandex.cloud.vpc.v1.CreateSubnetRequest\x1a!.yandex.cloud.operation.Operation\"<\x82\xd3\xe4\x93\x02\x14\"\x0f/vpc/v1/subnets:\x01*\xb2\xd2*\x1e\n\x14\x43reateSubnetMetadata\x12\x06Subnet\x12\x9f\x01\n\x06Update\x12(.yandex.cloud.vpc.v1.UpdateSubnetRequest\x1a!.yandex.cloud.operation.Operation\"H\x82\xd3\xe4\x93\x02 2\x1b/vpc/v1/subnets/{subnet_id}:\x01*\xb2\xd2*\x1e\n\x14UpdateSubnetMetadata\x12\x06Subnet\x12\xbd\x01\n\rAddCidrBlocks\x12/.yandex.cloud.vpc.v1.AddSubnetCidrBlocksRequest\x1a!.yandex.cloud.operation.Operation\"X\x82\xd3\xe4\x93\x02\x30\"+/vpc/v1/subnets/{subnet_id}:add-cidr-blocks:\x01*\xb2\xd2*\x1e\n\x14UpdateSubnetMetadata\x12\x06Subnet\x12\xc6\x01\n\x10RemoveCidrBlocks\x12\x32.yandex.cloud.vpc.v1.RemoveSubnetCidrBlocksRequest\x1a!.yandex.cloud.operation.Operation\"[\x82\xd3\xe4\x93\x02\x33\"./vpc/v1/subnets/{subnet_id}:remove-cidr-blocks:\x01*\xb2\xd2*\x1e\n\x14UpdateSubnetMetadata\x12\x06Subnet\x12\xab\x01\n\x06\x44\x65lete\x12(.yandex.cloud.vpc.v1.DeleteSubnetRequest\x1a!.yandex.cloud.operation.Operation\"T\x82\xd3\xe4\x93\x02\x1d*\x1b/vpc/v1/subnets/{subnet_id}\xb2\xd2*-\n\x14\x44\x65leteSubnetMetadata\x12\x15google.protobuf.Empty\x12\xa5\x01\n\x0eListOperations\x12\x30.yandex.cloud.vpc.v1.ListSubnetOperationsRequest\x1a\x31.yandex.cloud.vpc.v1.ListSubnetOperationsResponse\".\x82\xd3\xe4\x93\x02(\x12&/vpc/v1/subnets/{subnet_id}/operations\x12\x9e\x01\n\x04Move\x12&.yandex.cloud.vpc.v1.MoveSubnetRequest\x1a!.yandex.cloud.operation.Operation\"K\x82\xd3\xe4\x93\x02%\" /vpc/v1/subnets/{subnet_id}:move:\x01*\xb2\xd2*\x1c\n\x12MoveSubnetMetadata\x12\x06Subnet\x12\xa1\x01\n\x11ListUsedAddresses\x12-.yandex.cloud.vpc.v1.ListUsedAddressesRequest\x1a..yandex.cloud.vpc.v1.ListUsedAddressesResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/vpc/v1/subnets/{subnet_id}/addressesBV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_reference_dot_reference__pb2.DESCRIPTOR,])




_GETSUBNETREQUEST = _descriptor.Descriptor(
  name='GetSubnetRequest',
  full_name='yandex.cloud.vpc.v1.GetSubnetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.GetSubnetRequest.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=359,
)


_LISTSUBNETSREQUEST = _descriptor.Descriptor(
  name='ListSubnetsRequest',
  full_name='yandex.cloud.vpc.v1.ListSubnetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.vpc.v1.ListSubnetsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListSubnetsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListSubnetsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.vpc.v1.ListSubnetsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=362,
  serialized_end=505,
)


_LISTSUBNETSRESPONSE = _descriptor.Descriptor(
  name='ListSubnetsResponse',
  full_name='yandex.cloud.vpc.v1.ListSubnetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnets', full_name='yandex.cloud.vpc.v1.ListSubnetsResponse.subnets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListSubnetsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=507,
  serialized_end=599,
)


_CREATESUBNETREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.vpc.v1.CreateSubnetRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.vpc.v1.CreateSubnetRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.vpc.v1.CreateSubnetRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1060,
  serialized_end=1105,
)

_CREATESUBNETREQUEST = _descriptor.Descriptor(
  name='CreateSubnetRequest',
  full_name='yandex.cloud.vpc.v1.CreateSubnetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.vpc.v1.CreateSubnetRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.vpc.v1.CreateSubnetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.vpc.v1.CreateSubnetRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.vpc.v1.CreateSubnetRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.CreateSubnetRequest.network_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.vpc.v1.CreateSubnetRequest.zone_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v4_cidr_blocks', full_name='yandex.cloud.vpc.v1.CreateSubnetRequest.v4_cidr_blocks', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_table_id', full_name='yandex.cloud.vpc.v1.CreateSubnetRequest.route_table_id', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dhcp_options', full_name='yandex.cloud.vpc.v1.CreateSubnetRequest.dhcp_options', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATESUBNETREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=1105,
)


_CREATESUBNETMETADATA = _descriptor.Descriptor(
  name='CreateSubnetMetadata',
  full_name='yandex.cloud.vpc.v1.CreateSubnetMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.CreateSubnetMetadata.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1148,
)


_UPDATESUBNETREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.vpc.v1.UpdateSubnetRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.vpc.v1.UpdateSubnetRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.vpc.v1.UpdateSubnetRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1060,
  serialized_end=1105,
)

_UPDATESUBNETREQUEST = _descriptor.Descriptor(
  name='UpdateSubnetRequest',
  full_name='yandex.cloud.vpc.v1.UpdateSubnetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.UpdateSubnetRequest.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.vpc.v1.UpdateSubnetRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.vpc.v1.UpdateSubnetRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.vpc.v1.UpdateSubnetRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.vpc.v1.UpdateSubnetRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_table_id', full_name='yandex.cloud.vpc.v1.UpdateSubnetRequest.route_table_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dhcp_options', full_name='yandex.cloud.vpc.v1.UpdateSubnetRequest.dhcp_options', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATESUBNETREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1151,
  serialized_end=1608,
)


_UPDATESUBNETMETADATA = _descriptor.Descriptor(
  name='UpdateSubnetMetadata',
  full_name='yandex.cloud.vpc.v1.UpdateSubnetMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.UpdateSubnetMetadata.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1610,
  serialized_end=1651,
)


_ADDSUBNETCIDRBLOCKSREQUEST = _descriptor.Descriptor(
  name='AddSubnetCidrBlocksRequest',
  full_name='yandex.cloud.vpc.v1.AddSubnetCidrBlocksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.AddSubnetCidrBlocksRequest.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v4_cidr_blocks', full_name='yandex.cloud.vpc.v1.AddSubnetCidrBlocksRequest.v4_cidr_blocks', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1653,
  serialized_end=1738,
)


_ADDSUBNETCIDRBLOCKSMETADATA = _descriptor.Descriptor(
  name='AddSubnetCidrBlocksMetadata',
  full_name='yandex.cloud.vpc.v1.AddSubnetCidrBlocksMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.AddSubnetCidrBlocksMetadata.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1740,
  serialized_end=1788,
)


_REMOVESUBNETCIDRBLOCKSREQUEST = _descriptor.Descriptor(
  name='RemoveSubnetCidrBlocksRequest',
  full_name='yandex.cloud.vpc.v1.RemoveSubnetCidrBlocksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.RemoveSubnetCidrBlocksRequest.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v4_cidr_blocks', full_name='yandex.cloud.vpc.v1.RemoveSubnetCidrBlocksRequest.v4_cidr_blocks', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1790,
  serialized_end=1878,
)


_REMOVESUBNETCIDRBLOCKSMETADATA = _descriptor.Descriptor(
  name='RemoveSubnetCidrBlocksMetadata',
  full_name='yandex.cloud.vpc.v1.RemoveSubnetCidrBlocksMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.RemoveSubnetCidrBlocksMetadata.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1880,
  serialized_end=1931,
)


_DELETESUBNETREQUEST = _descriptor.Descriptor(
  name='DeleteSubnetRequest',
  full_name='yandex.cloud.vpc.v1.DeleteSubnetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.DeleteSubnetRequest.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1933,
  serialized_end=1987,
)


_DELETESUBNETMETADATA = _descriptor.Descriptor(
  name='DeleteSubnetMetadata',
  full_name='yandex.cloud.vpc.v1.DeleteSubnetMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.DeleteSubnetMetadata.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1989,
  serialized_end=2030,
)


_LISTSUBNETOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListSubnetOperationsRequest',
  full_name='yandex.cloud.vpc.v1.ListSubnetOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.ListSubnetOperationsRequest.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListSubnetOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListSubnetOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2032,
  serialized_end=2156,
)


_LISTSUBNETOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListSubnetOperationsResponse',
  full_name='yandex.cloud.vpc.v1.ListSubnetOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.vpc.v1.ListSubnetOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListSubnetOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2158,
  serialized_end=2268,
)


_MOVESUBNETREQUEST = _descriptor.Descriptor(
  name='MoveSubnetRequest',
  full_name='yandex.cloud.vpc.v1.MoveSubnetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.MoveSubnetRequest.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.vpc.v1.MoveSubnetRequest.destination_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2270,
  serialized_end=2367,
)


_MOVESUBNETMETADATA = _descriptor.Descriptor(
  name='MoveSubnetMetadata',
  full_name='yandex.cloud.vpc.v1.MoveSubnetMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.MoveSubnetMetadata.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2369,
  serialized_end=2408,
)


_LISTUSEDADDRESSESREQUEST = _descriptor.Descriptor(
  name='ListUsedAddressesRequest',
  full_name='yandex.cloud.vpc.v1.ListUsedAddressesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.vpc.v1.ListUsedAddressesRequest.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListUsedAddressesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListUsedAddressesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.vpc.v1.ListUsedAddressesRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2410,
  serialized_end=2516,
)


_LISTUSEDADDRESSESRESPONSE = _descriptor.Descriptor(
  name='ListUsedAddressesResponse',
  full_name='yandex.cloud.vpc.v1.ListUsedAddressesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='yandex.cloud.vpc.v1.ListUsedAddressesResponse.addresses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListUsedAddressesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2518,
  serialized_end=2623,
)


_USEDADDRESS = _descriptor.Descriptor(
  name='UsedAddress',
  full_name='yandex.cloud.vpc.v1.UsedAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.vpc.v1.UsedAddress.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_version', full_name='yandex.cloud.vpc.v1.UsedAddress.ip_version', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='references', full_name='yandex.cloud.vpc.v1.UsedAddress.references', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2626,
  serialized_end=2763,
)

_LISTSUBNETSRESPONSE.fields_by_name['subnets'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2._SUBNET
_CREATESUBNETREQUEST_LABELSENTRY.containing_type = _CREATESUBNETREQUEST
_CREATESUBNETREQUEST.fields_by_name['labels'].message_type = _CREATESUBNETREQUEST_LABELSENTRY
_CREATESUBNETREQUEST.fields_by_name['dhcp_options'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2._DHCPOPTIONS
_UPDATESUBNETREQUEST_LABELSENTRY.containing_type = _UPDATESUBNETREQUEST
_UPDATESUBNETREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATESUBNETREQUEST.fields_by_name['labels'].message_type = _UPDATESUBNETREQUEST_LABELSENTRY
_UPDATESUBNETREQUEST.fields_by_name['dhcp_options'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2._DHCPOPTIONS
_LISTSUBNETOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
_LISTUSEDADDRESSESRESPONSE.fields_by_name['addresses'].message_type = _USEDADDRESS
_USEDADDRESS.fields_by_name['ip_version'].enum_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2._IPVERSION
_USEDADDRESS.fields_by_name['references'].message_type = yandex_dot_cloud_dot_reference_dot_reference__pb2._REFERENCE
DESCRIPTOR.message_types_by_name['GetSubnetRequest'] = _GETSUBNETREQUEST
DESCRIPTOR.message_types_by_name['ListSubnetsRequest'] = _LISTSUBNETSREQUEST
DESCRIPTOR.message_types_by_name['ListSubnetsResponse'] = _LISTSUBNETSRESPONSE
DESCRIPTOR.message_types_by_name['CreateSubnetRequest'] = _CREATESUBNETREQUEST
DESCRIPTOR.message_types_by_name['CreateSubnetMetadata'] = _CREATESUBNETMETADATA
DESCRIPTOR.message_types_by_name['UpdateSubnetRequest'] = _UPDATESUBNETREQUEST
DESCRIPTOR.message_types_by_name['UpdateSubnetMetadata'] = _UPDATESUBNETMETADATA
DESCRIPTOR.message_types_by_name['AddSubnetCidrBlocksRequest'] = _ADDSUBNETCIDRBLOCKSREQUEST
DESCRIPTOR.message_types_by_name['AddSubnetCidrBlocksMetadata'] = _ADDSUBNETCIDRBLOCKSMETADATA
DESCRIPTOR.message_types_by_name['RemoveSubnetCidrBlocksRequest'] = _REMOVESUBNETCIDRBLOCKSREQUEST
DESCRIPTOR.message_types_by_name['RemoveSubnetCidrBlocksMetadata'] = _REMOVESUBNETCIDRBLOCKSMETADATA
DESCRIPTOR.message_types_by_name['DeleteSubnetRequest'] = _DELETESUBNETREQUEST
DESCRIPTOR.message_types_by_name['DeleteSubnetMetadata'] = _DELETESUBNETMETADATA
DESCRIPTOR.message_types_by_name['ListSubnetOperationsRequest'] = _LISTSUBNETOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListSubnetOperationsResponse'] = _LISTSUBNETOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['MoveSubnetRequest'] = _MOVESUBNETREQUEST
DESCRIPTOR.message_types_by_name['MoveSubnetMetadata'] = _MOVESUBNETMETADATA
DESCRIPTOR.message_types_by_name['ListUsedAddressesRequest'] = _LISTUSEDADDRESSESREQUEST
DESCRIPTOR.message_types_by_name['ListUsedAddressesResponse'] = _LISTUSEDADDRESSESRESPONSE
DESCRIPTOR.message_types_by_name['UsedAddress'] = _USEDADDRESS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSubnetRequest = _reflection.GeneratedProtocolMessageType('GetSubnetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSUBNETREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.GetSubnetRequest)
  })
_sym_db.RegisterMessage(GetSubnetRequest)

ListSubnetsRequest = _reflection.GeneratedProtocolMessageType('ListSubnetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSUBNETSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListSubnetsRequest)
  })
_sym_db.RegisterMessage(ListSubnetsRequest)

ListSubnetsResponse = _reflection.GeneratedProtocolMessageType('ListSubnetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSUBNETSRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListSubnetsResponse)
  })
_sym_db.RegisterMessage(ListSubnetsResponse)

CreateSubnetRequest = _reflection.GeneratedProtocolMessageType('CreateSubnetRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESUBNETREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateSubnetRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATESUBNETREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateSubnetRequest)
  })
_sym_db.RegisterMessage(CreateSubnetRequest)
_sym_db.RegisterMessage(CreateSubnetRequest.LabelsEntry)

CreateSubnetMetadata = _reflection.GeneratedProtocolMessageType('CreateSubnetMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBNETMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateSubnetMetadata)
  })
_sym_db.RegisterMessage(CreateSubnetMetadata)

UpdateSubnetRequest = _reflection.GeneratedProtocolMessageType('UpdateSubnetRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATESUBNETREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateSubnetRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATESUBNETREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateSubnetRequest)
  })
_sym_db.RegisterMessage(UpdateSubnetRequest)
_sym_db.RegisterMessage(UpdateSubnetRequest.LabelsEntry)

UpdateSubnetMetadata = _reflection.GeneratedProtocolMessageType('UpdateSubnetMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESUBNETMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateSubnetMetadata)
  })
_sym_db.RegisterMessage(UpdateSubnetMetadata)

AddSubnetCidrBlocksRequest = _reflection.GeneratedProtocolMessageType('AddSubnetCidrBlocksRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDSUBNETCIDRBLOCKSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.AddSubnetCidrBlocksRequest)
  })
_sym_db.RegisterMessage(AddSubnetCidrBlocksRequest)

AddSubnetCidrBlocksMetadata = _reflection.GeneratedProtocolMessageType('AddSubnetCidrBlocksMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDSUBNETCIDRBLOCKSMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.AddSubnetCidrBlocksMetadata)
  })
_sym_db.RegisterMessage(AddSubnetCidrBlocksMetadata)

RemoveSubnetCidrBlocksRequest = _reflection.GeneratedProtocolMessageType('RemoveSubnetCidrBlocksRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVESUBNETCIDRBLOCKSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.RemoveSubnetCidrBlocksRequest)
  })
_sym_db.RegisterMessage(RemoveSubnetCidrBlocksRequest)

RemoveSubnetCidrBlocksMetadata = _reflection.GeneratedProtocolMessageType('RemoveSubnetCidrBlocksMetadata', (_message.Message,), {
  'DESCRIPTOR' : _REMOVESUBNETCIDRBLOCKSMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.RemoveSubnetCidrBlocksMetadata)
  })
_sym_db.RegisterMessage(RemoveSubnetCidrBlocksMetadata)

DeleteSubnetRequest = _reflection.GeneratedProtocolMessageType('DeleteSubnetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESUBNETREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.DeleteSubnetRequest)
  })
_sym_db.RegisterMessage(DeleteSubnetRequest)

DeleteSubnetMetadata = _reflection.GeneratedProtocolMessageType('DeleteSubnetMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETESUBNETMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.DeleteSubnetMetadata)
  })
_sym_db.RegisterMessage(DeleteSubnetMetadata)

ListSubnetOperationsRequest = _reflection.GeneratedProtocolMessageType('ListSubnetOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSUBNETOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListSubnetOperationsRequest)
  })
_sym_db.RegisterMessage(ListSubnetOperationsRequest)

ListSubnetOperationsResponse = _reflection.GeneratedProtocolMessageType('ListSubnetOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSUBNETOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListSubnetOperationsResponse)
  })
_sym_db.RegisterMessage(ListSubnetOperationsResponse)

MoveSubnetRequest = _reflection.GeneratedProtocolMessageType('MoveSubnetRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVESUBNETREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.MoveSubnetRequest)
  })
_sym_db.RegisterMessage(MoveSubnetRequest)

MoveSubnetMetadata = _reflection.GeneratedProtocolMessageType('MoveSubnetMetadata', (_message.Message,), {
  'DESCRIPTOR' : _MOVESUBNETMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.MoveSubnetMetadata)
  })
_sym_db.RegisterMessage(MoveSubnetMetadata)

ListUsedAddressesRequest = _reflection.GeneratedProtocolMessageType('ListUsedAddressesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSEDADDRESSESREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListUsedAddressesRequest)
  })
_sym_db.RegisterMessage(ListUsedAddressesRequest)

ListUsedAddressesResponse = _reflection.GeneratedProtocolMessageType('ListUsedAddressesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSEDADDRESSESRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListUsedAddressesResponse)
  })
_sym_db.RegisterMessage(ListUsedAddressesResponse)

UsedAddress = _reflection.GeneratedProtocolMessageType('UsedAddress', (_message.Message,), {
  'DESCRIPTOR' : _USEDADDRESS,
  '__module__' : 'yandex.cloud.vpc.v1.subnet_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UsedAddress)
  })
_sym_db.RegisterMessage(UsedAddress)


DESCRIPTOR._options = None
_GETSUBNETREQUEST.fields_by_name['subnet_id']._options = None
_LISTSUBNETSREQUEST.fields_by_name['folder_id']._options = None
_LISTSUBNETSREQUEST.fields_by_name['page_size']._options = None
_LISTSUBNETSREQUEST.fields_by_name['page_token']._options = None
_LISTSUBNETSREQUEST.fields_by_name['filter']._options = None
_CREATESUBNETREQUEST_LABELSENTRY._options = None
_CREATESUBNETREQUEST.fields_by_name['folder_id']._options = None
_CREATESUBNETREQUEST.fields_by_name['name']._options = None
_CREATESUBNETREQUEST.fields_by_name['description']._options = None
_CREATESUBNETREQUEST.fields_by_name['labels']._options = None
_CREATESUBNETREQUEST.fields_by_name['network_id']._options = None
_CREATESUBNETREQUEST.fields_by_name['zone_id']._options = None
_CREATESUBNETREQUEST.fields_by_name['v4_cidr_blocks']._options = None
_CREATESUBNETREQUEST.fields_by_name['route_table_id']._options = None
_UPDATESUBNETREQUEST_LABELSENTRY._options = None
_UPDATESUBNETREQUEST.fields_by_name['subnet_id']._options = None
_UPDATESUBNETREQUEST.fields_by_name['name']._options = None
_UPDATESUBNETREQUEST.fields_by_name['description']._options = None
_UPDATESUBNETREQUEST.fields_by_name['labels']._options = None
_UPDATESUBNETREQUEST.fields_by_name['route_table_id']._options = None
_ADDSUBNETCIDRBLOCKSREQUEST.fields_by_name['subnet_id']._options = None
_REMOVESUBNETCIDRBLOCKSREQUEST.fields_by_name['subnet_id']._options = None
_DELETESUBNETREQUEST.fields_by_name['subnet_id']._options = None
_LISTSUBNETOPERATIONSREQUEST.fields_by_name['subnet_id']._options = None
_LISTSUBNETOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTSUBNETOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_MOVESUBNETREQUEST.fields_by_name['subnet_id']._options = None
_MOVESUBNETREQUEST.fields_by_name['destination_folder_id']._options = None
_LISTUSEDADDRESSESREQUEST.fields_by_name['subnet_id']._options = None

_SUBNETSERVICE = _descriptor.ServiceDescriptor(
  name='SubnetService',
  full_name='yandex.cloud.vpc.v1.SubnetService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2766,
  serialized_end=4381,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.vpc.v1.SubnetService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSUBNETREQUEST,
    output_type=yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2._SUBNET,
    serialized_options=b'\202\323\344\223\002\035\022\033/vpc/v1/subnets/{subnet_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.vpc.v1.SubnetService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSUBNETSREQUEST,
    output_type=_LISTSUBNETSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/vpc/v1/subnets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.vpc.v1.SubnetService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATESUBNETREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\024\"\017/vpc/v1/subnets:\001*\262\322*\036\n\024CreateSubnetMetadata\022\006Subnet',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.vpc.v1.SubnetService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATESUBNETREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 2\033/vpc/v1/subnets/{subnet_id}:\001*\262\322*\036\n\024UpdateSubnetMetadata\022\006Subnet',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddCidrBlocks',
    full_name='yandex.cloud.vpc.v1.SubnetService.AddCidrBlocks',
    index=4,
    containing_service=None,
    input_type=_ADDSUBNETCIDRBLOCKSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0020\"+/vpc/v1/subnets/{subnet_id}:add-cidr-blocks:\001*\262\322*\036\n\024UpdateSubnetMetadata\022\006Subnet',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveCidrBlocks',
    full_name='yandex.cloud.vpc.v1.SubnetService.RemoveCidrBlocks',
    index=5,
    containing_service=None,
    input_type=_REMOVESUBNETCIDRBLOCKSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0023\"./vpc/v1/subnets/{subnet_id}:remove-cidr-blocks:\001*\262\322*\036\n\024UpdateSubnetMetadata\022\006Subnet',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.vpc.v1.SubnetService.Delete',
    index=6,
    containing_service=None,
    input_type=_DELETESUBNETREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\035*\033/vpc/v1/subnets/{subnet_id}\262\322*-\n\024DeleteSubnetMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.vpc.v1.SubnetService.ListOperations',
    index=7,
    containing_service=None,
    input_type=_LISTSUBNETOPERATIONSREQUEST,
    output_type=_LISTSUBNETOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/vpc/v1/subnets/{subnet_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Move',
    full_name='yandex.cloud.vpc.v1.SubnetService.Move',
    index=8,
    containing_service=None,
    input_type=_MOVESUBNETREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002%\" /vpc/v1/subnets/{subnet_id}:move:\001*\262\322*\034\n\022MoveSubnetMetadata\022\006Subnet',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUsedAddresses',
    full_name='yandex.cloud.vpc.v1.SubnetService.ListUsedAddresses',
    index=9,
    containing_service=None,
    input_type=_LISTUSEDADDRESSESREQUEST,
    output_type=_LISTUSEDADDRESSESRESPONSE,
    serialized_options=b'\202\323\344\223\002\'\022%/vpc/v1/subnets/{subnet_id}/addresses',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SUBNETSERVICE)

DESCRIPTOR.services_by_name['SubnetService'] = _SUBNETSERVICE

# @@protoc_insertion_point(module_scope)
